@@ -1,10 +1,10 @@
 import React from 'react';
-import { shallow } from 'enzyme';
+import { mount } from 'enzyme';
 import { Tab } from '../Tab';
 import { TabTitleText } from '../TabTitleText';
 
 test('should not render anything', () => {
-  const view = shallow(
+  const view = mount(
   <Tab eventKey={0} title={<TabTitleText>"Tab item 1"</TabTitleText>}>
       Tab 1 section
     </Tab>
