@@ -1,3 +1,12 @@
+/**
+ * Copyright IBM Corp. 2016, 2018
+ *
+ * This source code is licensed under the Apache-2.0 license found in the
+ * LICENSE file in the root directory of this source tree.
+ */
+
+import warning from 'warning';
+import { breakingChangesX } from '../../globals/js/feature-flags';
 import settings from '../../globals/js/settings';
 import mixin from '../../globals/js/misc/mixin';
 import createComponent from '../../globals/js/mixins/create-component';
@@ -5,6 +14,11 @@ import initComponentBySearch from '../../globals/js/mixins/init-component-by-sea
 import handles from '../../globals/js/mixins/handles';
 import eventMatches from '../../globals/js/misc/event-matches';
 import on from '../../globals/js/misc/on';
+import removedComponent from '../removed-component';
+
+let didWarnAboutDeprecation;
+
+const toArray = arrayLike => Array.prototype.slice.call(arrayLike);
 
 class LeftNav extends mixin(createComponent, initComponentBySearch, handles) {
   /**
@@ -40,6 +54,13 @@ class LeftNav extends mixin(createComponent, initComponentBySearch, handles) {
    */
   constructor(element, options) {
     super(element, options);
+    if (__DEV__) {
+      warning(
+        didWarnAboutDeprecation,
+        'The `LeftNav` component in `carbon-components` has been deprecated. It will be removed in the next major release.'
+      );
+      didWarnAboutDeprecation = true;
+    }
     this.leftNavSectionActive = false;
     this.hookOpenActions();
     this.hookListSectionEvents();
@@ -112,8 +133,8 @@ class LeftNav extends mixin(createComponent, initComponentBySearch, handles) {
       `${this.options.selectorLeftNavList}:not(${this.options.selectorLeftNavMainNavHidden})`
     );
     const newLeftNavList = this.element.querySelector(`[data-left-nav-list=${selectedNavTitle}]`);
-    const currentLeftNavItems = [...currentLeftNavList.querySelectorAll(this.options.selectorLeftNavListItem)].reverse();
-    const newLeftNavItems = [...newLeftNavList.querySelectorAll(this.options.selectorLeftNavListItem)];
+    const currentLeftNavItems = toArray(currentLeftNavList.querySelectorAll(this.options.selectorLeftNavListItem)).reverse();
+    const newLeftNavItems = toArray(newLeftNavList.querySelectorAll(this.options.selectorLeftNavListItem));
 
     const fadeOutTime = 300;
     let counter = 0;
@@ -215,7 +236,7 @@ class LeftNav extends mixin(createComponent, initComponentBySearch, handles) {
    * Adds event listeners to list items
    */
   hookListItemsEvents() {
-    const leftNavList = [...this.element.querySelectorAll(this.options.selectorLeftNavList)];
+    const leftNavList = toArray(this.element.querySelectorAll(this.options.selectorLeftNavList));
     leftNavList.forEach(list => {
       this.manage(
         on(list, 'click', evt => {
@@ -275,7 +296,7 @@ class LeftNav extends mixin(createComponent, initComponentBySearch, handles) {
         })
       );
     });
-    const flyouts = [...this.element.ownerDocument.querySelectorAll(this.options.selectorLeftNavListItemHasFlyout)];
+    const flyouts = toArray(this.element.ownerDocument.querySelectorAll(this.options.selectorLeftNavListItemHasFlyout));
     flyouts.forEach(flyout => {
       this.manage(
         on(flyout, 'mouseenter', () => {
@@ -302,7 +323,7 @@ class LeftNav extends mixin(createComponent, initComponentBySearch, handles) {
    * Hides all flyout menus.
    */
   hideAllFlyoutMenus() {
-    const flyoutMenus = [...this.element.querySelectorAll(this.options.selectorLeftNavFlyoutMenu)];
+    const flyoutMenus = toArray(this.element.querySelectorAll(this.options.selectorLeftNavFlyoutMenu));
     flyoutMenus.forEach(menu => {
       menu.setAttribute('aria-hidden', 'true');
       menu.classList.remove(this.options.classFlyoutDisplayed);
@@ -314,7 +335,7 @@ class LeftNav extends mixin(createComponent, initComponentBySearch, handles) {
    * @param {Object} item The active list item.
    */
   addActiveListItem(item) {
-    [...this.element.querySelectorAll(this.options.selectorLeftNavAllListItems)].forEach(currentItem => {
+    toArray(this.element.querySelectorAll(this.options.selectorLeftNavAllListItems)).forEach(currentItem => {
       if (!(item === currentItem)) {
         if (!currentItem.contains(item)) {
           currentItem.classList.remove(this.options.classActiveLeftNavListItem);
@@ -323,7 +344,7 @@ class LeftNav extends mixin(createComponent, initComponentBySearch, handles) {
         }
       }
     });
-    [...this.element.querySelectorAll(this.options.selectorLeftNavNestedListItem)].forEach(currentItem => {
+    toArray(this.element.querySelectorAll(this.options.selectorLeftNavNestedListItem)).forEach(currentItem => {
       if (!(item === currentItem)) {
         currentItem.classList.remove(this.options.classActiveLeftNavListItem);
       }
@@ -373,7 +394,7 @@ class LeftNav extends mixin(createComponent, initComponentBySearch, handles) {
     const isOpen = listItem.classList.contains(this.options.classExpandedLeftNavListItem);
     this.hideAllFlyoutMenus();
     listItem.classList.toggle(this.options.classExpandedLeftNavListItem, !isOpen);
-    const listItems = [...listItem.querySelectorAll(this.options.selectorLeftNavNestedListItem)];
+    const listItems = toArray(listItem.querySelectorAll(this.options.selectorLeftNavNestedListItem));
     listItems.forEach(item => {
       if (isOpen) {
         listItem.querySelector(this.options.selectorLeftNavNestedList).setAttribute('aria-hidden', 'true');
@@ -534,7 +555,7 @@ class LeftNav extends mixin(createComponent, initComponentBySearch, handles) {
    * @member LeftNav.components
    * @type {WeakMap}
    */
-  static components = new WeakMap();
+  static components /* #__PURE_CLASS_PROPERTY__ */ = new WeakMap();
 }
 
-export default LeftNav;
+export default (!breakingChangesX ? LeftNav : removedComponent('LeftNav'));
